%define path_to_vi /bin/vi
%define path_to_sendmail /usr/sbin/sendmail
Summary: A system integrity assessment tool.
Name: tripwire
Version: 2.3.1
Release: 18.3AX
Epoch: 0
License: GPL
Group:   Applications/System
Source0: http://download.sourceforge.net/tripwire/tripwire-2.3.1-2.tar.gz
Source1: tripwire.cron.in
Source2: tripwire.txt
Source3: tripwire.gif
Source4: twcfg.txt.in
Source5: twinstall.sh.in
Source6: twpol.txt.in
Source7: README.RPM
Source8: Latest-Changes
Source9: License-Issues
URL: http://www.tripwire.org/
Buildrequires: autoconf, openssl-devel
Requires: sed, grep, gzip, tar, gawk
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Tripwire is NOT 64bit clean, nor endian clean, and only works properly
# on x86 architecture. The open source code doesn't seem to be maintained,
# so this is probably unlikely to change.  We exclude non x86 arches.
ExclusiveArch: %{ix86}

Patch0: tripwire-2.3.0-50-rfc822.patch
Patch1: tripwire-mkstemp.patch
Patch2: tw-20030919.patch
Patch3: tripwire-2.3.1-gcc3.new.patch
Patch4: tripwire-2.3.1-pipedmail.patch

%description
Tripwire is a very valuable security tool for Linux systems, if it is
installed to a clean system. Tripwire should be installed right after
the OS installation, and before you have connected your system to a
network (i.e., before any possibility exists that someone could alter
files on your system).

When Tripwire is initially set up, it creates a database that records
certain file information. Then when it is run, it compares a
designated set of files and directories to the information stored in
the database. Added or deleted files are flagged and reported, as are
any files that have changed from their previously recorded state in
the database. When Tripwire is run against system files on a regular
basis, any file changes will be spotted when Tripwire is run.
Tripwire will report the changes, which will give system
administrators a clue that they need to enact damage control measures
immediately if certain files have been altered.

After installing this package, run %{_sysconfdir}/tripwire/twinstall.sh to
generate cryptographic keys and run tripwire --init to initialize the
database.

%prep
%setup -q -n %{name}-2.3.1-2
cp -p %{SOURCE2} quickstart.txt
cp -p %{SOURCE3} quickstart.gif

%patch0 -p1 -b .rfc822
%patch1 -p1 -b .mkstemp
%patch2 -p1 -b .tw-20030919
%patch3 -p1 -b .gcc3.new
%patch4 -p0 -b .pipedmail

%build
chmod 755 configure
# RPM_OPT_FLAGS break the code (deadlock).
export CXXFLAGS="-O -Wall -pipe -g"
./configure \
	path_to_vi=%{path_to_vi} \
	path_to_sendmail=%{path_to_sendmail} \
	--prefix=/ \
	--sysconfdir=%{_sysconfdir}/tripwire \
	--sbindir=%{_sbindir} \
	--libdir=%{_var}/lib \
	--mandir=%{_mandir}

# Do not parallelize this with _smp_flags or -j
make

%install
rm -fr ${RPM_BUILD_ROOT}

# Install the binaries.
mkdir -p ${RPM_BUILD_ROOT}%{_sbindir}
install -p -m755 bin/siggen   ${RPM_BUILD_ROOT}%{_sbindir}
install -p -m755 bin/tripwire ${RPM_BUILD_ROOT}%{_sbindir}
install -p -m755 bin/twadmin  ${RPM_BUILD_ROOT}%{_sbindir}
install -p -m755 bin/twprint  ${RPM_BUILD_ROOT}%{_sbindir}

# Install the man pages.
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/{man4,man5,man8}
install -p -m644 man/man4/*.4 ${RPM_BUILD_ROOT}%{_mandir}/man4/
install -p -m644 man/man5/*.5 ${RPM_BUILD_ROOT}%{_mandir}/man5/
install -p -m644 man/man8/*.8 ${RPM_BUILD_ROOT}%{_mandir}/man8/

# Create configuration files from templates.
rm -rf _tmpcfg
mkdir _tmpcfg
for infile in %{SOURCE1} %{SOURCE4} %{SOURCE5} %{SOURCE6} ; do
	outfile=${infile##/*/}
	outfile=${outfile%.*n}
	cat ${infile} |\
	sed -e 's|@path_to_vi@|%{path_to_vi}|g' |\
	sed -e 's|@path_to_sendmail@|%{path_to_sendmail}|g' |\
	sed -e 's|@sysconfdir@|%{_sysconfdir}|g' |\
	sed -e 's|@sbindir@|%{_sbindir}|g' |\
	sed -e 's|@vardir@|%{_var}|g' >\
	_tmpcfg/${outfile}
done

# Create the reports directory.
install -d -m700 ${RPM_BUILD_ROOT}%{_var}/lib/tripwire/report

# Install the cron job.
install -d -m755 ${RPM_BUILD_ROOT}%{_sysconfdir}/cron.daily
install -p -m755 _tmpcfg/tripwire.cron \
    ${RPM_BUILD_ROOT}%{_sysconfdir}/cron.daily/tripwire-check
rm _tmpcfg/tripwire.cron

# Install configuration files.
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/tripwire
for file in _tmpcfg/* ; do
    install -p -m644 ${file} ${RPM_BUILD_ROOT}%{_sysconfdir}/tripwire
done

# Fix permissions on documentation files.
cp -p %{SOURCE7} %{SOURCE8} %{SOURCE9} .
chmod 644 README Release_Notes ChangeLog COPYING TRADEMARK quickstart.gif quickstart.txt README.RPM policy/policyguide.txt Latest-Changes License-Issues

%clean
rm -fr ${RPM_BUILD_ROOT}

%files
%defattr(-,root,root,-)
%doc      README Release_Notes ChangeLog COPYING TRADEMARK quickstart.gif quickstart.txt README.RPM policy/policyguide.txt Latest-Changes License-Issues
%attr(0755,root,root) %dir %{_sysconfdir}/tripwire
%attr(0755,root,root) %{_sysconfdir}/tripwire/twinstall.sh
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/tripwire/twcfg.txt
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/tripwire/twpol.txt
%attr(0755,root,root) %config(noreplace) %{_sysconfdir}/cron.daily/tripwire-check
%attr(0755,root,root) %dir %{_var}/lib/tripwire
%attr(0755,root,root) %dir %{_var}/lib/tripwire/report
%attr(0644,root,root) %{_mandir}/*/*
%attr(0755,root,root) %{_sbindir}/*

%changelog
* Mon Jun  7 2004 Shiro Yamada <shiro@miraclelinux.com> 2.3.1-18.3AX
- security fix for pipedmail (patch#4)

* Mon May 31 2004 Shiro Yamada <shiro@miraclelinux.com> 2.3.1-18.2AX
- updated default policy file

* Thu May 27 2004 Shiro Yamada <shiro@miraclelinux.com> 2.3.1-18.1AX
- rebuild for Asianux 1.0

* Fri Nov 28 2003 Keith G. Robertson-Turner <tripwire-devel@genesis-x.nildram.co.uk> 0:2.3.1-18.fdr.3
- Thanks to Michael Schwendt for really cleaning up the Spec file
- The remaining parts of the original tripwire-2.3.1-gcc3.patch have now been implemented 
- Debuginfo fully builds now

* Thu Nov 27 2003 Keith G. Robertson-Turner <tripwire-devel@genesis-x.nildram.co.uk> 0:2.3.1-18.fdr.2
- Removed version specific grep dependency, since grep >= 2.3 is common
- Added openssl-devel and autoconf to build dependencies
- The tripwire-jbj.patch is now confirmed to be merged with tw-20030919.patch
- Added RPM optimization flags option, disabled by default since it breaks the code
- Fixed file permissions of packaged files

* Wed Nov 26 2003 Keith G. Robertson-Turner <tripwire-devel@genesis-x.nildram.co.uk> 0:2.3.1-18.fdr.1
- Implemented Paul Herman's tw-20030919.patch
- Removed the fhs gcc3 and jbj patches, which are now broken/obsoleted by the above
- Both the mkstemp and rfc822 patches are still implemented
- Build uses autoconf for now
- Spec file given complete overhaul for stricter compliance. Still more to do

* Wed Jan 22 2003 Tim Powers <timp@redhat.com>
- rebuilt

* Sat Nov 16 2002 Jeff Johnson <jbj@redhat.com> 2.3.1-16
- rebuild from cvs.
- comment out debug messages to achieve compilation.
- include policyguide.txt (#72259).
- use mkstemp, not mktemp.

* Fri Aug 02 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-14
- Modified default sample twpol file to remove bogus warnings (#70502)

* Fri Jun 21 2002 Tim Powers <timp@redhat.com> 2.3.1-13
- automated rebuild

* Sun May 26 2002 Tim Powers <timp@redhat.com> 2.3.1-12
- automated rebuild

* Wed May 22 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-11
- Rebuilt in new build environment with gcc 3.1

* Tue Feb 26 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-9
- Conditionalized gcc3 patch
- Added back the ExclusiveArch that is required but disappeared somewhere along
  the line.
- Rebuild in new build environment

* Thu Jan 31 2002 Mike A. Harris <mharris@redhat.com> 2.3.1-7
- Bump release and rebuild in new environment.
- (Elliot Lee) Add patch to make it build with gcc3.

* Thu Aug  9 2001 Nalin Dahyabhai <nalin@redhat.com> 2.3.1-5
- define USE_FHS when USES_FHS is defined, so that the database winds up
  in the right directory (#51332)
- update default twpol file to include files recently-added to the full
  installation tree

* Tue Jul 17 2001 Mike A. Harris <mharris@redhat.com> 2.3.1-4
- Applied bugfix for (#47276) to make tripwire email RFC822 compliant, using
  patch in bugreport from Michael Schwendt <mschwendt@yahoo.com>

* Tue Jul 10 2001 Mike A. Harris <mharris@redhat.com> 2.3.1-3
- Made package own dir /var/lib/tripwire
 
* Mon Jun 25 2001 Nalin Dahyabhai <nalin@redhat.com>
- update to 2.3.1-2

* Thu Mar  1 2001 Bill Nottingham <notting@redhat.com>
- rebuild, fix defattr. Weird.

* Tue Feb 27 2001 Nalin Dahyabhai <nalin@redhat.com>
- refresh from upstream
- modify the default policy to match the current tree more closely (#28744)
- make the text files 0644, not 0755
- defattr for the sake of the docs

* Wed Sep 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- change exclusivearch: i386 to exclusivearch: %%{ix86} (#17759)

* Wed Aug 23 2000 Than Ngo <than@redhat.com>
- remove copyleft information in specfile (Bug #16765)

* Tue Aug 22 2000 Nalin Dahyabhai <nalin@redhat.com>
- remove duplicate source files
- sync up description with specspo

* Fri Aug 4 2000 Than Ngo <than@redhat.de>
- remove Vendor and Distribution from specfile (Bug #15246)

* Fri Aug 4 2000 Than Ngo <than@redhat.de>
- starts tripwire --check if it was configured before. (Bug #15384)

* Fri Aug 4 2000 Nalin Dahyabhai <nalin@redhat.com>
- fix sense of checking for the database's existence in the cron job
- actually include twinstall.sh, twcfg.txt, twpol.txt

* Thu Aug 3 2000 Than Ngo <than@redhat.de>
- permission fix (bug #15246)

* Mon Jul 31 2000 Nalin Dahyabhai <nalin@redhat.com>
- add quickstart docs (Ed)
- tweak description text (Ed)

* Thu Jul 20 2000 Nalin Dahyabhai <nalin@redhat.com>
- update .spec file to follow RPM conventions
- add tripwire --check to cron.daily

